==> qtjambi-dbus-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDBus/QDBusPendingCallWatcher_shell.h <==
#ifndef QDBUSPENDINGCALLWATCHER_SHELL_H
#define QDBUSPENDINGCALLWATCHER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDBus/qdbuspendingcall.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <QtJambi/RegistryAPI>


class QDBusPendingCallWatcher_shell : public QDBusPendingCallWatcher, public QtJambiShellInterface
{
public:
    QDBusPendingCallWatcher_shell(const QDBusPendingCall& call0, QObject* parent1 = nullptr);
    ~QDBusPendingCallWatcher_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusPendingCallWatcher_access : public QDBusPendingCallWatcher
{
};

#endif // QDBUSPENDINGCALLWATCHER_SHELL_H

==> qtjambi-dbus-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiDBus/QDBusPendingCallWatcher_shell.h <==
#ifndef QDBUSPENDINGCALLWATCHER_SHELL_H
#define QDBUSPENDINGCALLWATCHER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDBus/qdbuspendingcall.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <QtJambi/RegistryAPI>


class QDBusPendingCallWatcher_shell : public QDBusPendingCallWatcher, public QtJambiShellInterface
{
public:
    QDBusPendingCallWatcher_shell(const QDBusPendingCall& call0, QObject* parent1 = nullptr);
    ~QDBusPendingCallWatcher_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusPendingCallWatcher_access : public QDBusPendingCallWatcher
{
};

#endif // QDBUSPENDINGCALLWATCHER_SHELL_H
